import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_eks._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_ssm._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "eks-spot-blocks", "0.2.354", __name__[0:-6], "eks-spot-blocks@0.2.354.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
